@@ -17,15 +17,15 @@ use Data::Compare; # Exports Compare()
 $Storable::Deparse  = 1;
 $Storable::Eval     = 1;
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 use Class::Tiny {
-    registry    => sub {{}},
-    events      => sub {EventStore::Tiny::EventStream->new(
-                        logger => shift->logger)},
-    init_data   => sub {{}},
-    logger      => sub {EventStore::Tiny::Logger->log_cb},
-    cache_size  => 0, # Default: store snapshot every time. no caching: undef
+    registry        => sub {{}},
+    events          => sub {EventStore::Tiny::EventStream->new(
+                             logger => shift->logger)},
+    init_data       => sub {{}},
+    logger          => sub {EventStore::Tiny::Logger->log_cb},
+    cache_distance  => 0, # Default: store snapshot each time. no caching: undef
 }, '_cached_snapshot';
 
 # Class method to construct
@@ -99,7 +99,7 @@ sub snapshot {
     );
 
     # Caching disabled: done
-    return $snapshot unless defined $self->cache_size;
+    return $snapshot unless defined $self->cache_distance;
 
     # Cache snapshot if no cache present yet, but neccessary
     $self->_cached_snapshot($snapshot)
@@ -107,7 +107,7 @@ sub snapshot {
 
     # Cache snapshot if new event count > cache size
     $self->_cached_snapshot($snapshot)
-        if @{$es->events} > $self->cache_size;
+        if @{$es->events} > $self->cache_distance;
 
     # Done
     return $snapshot;
@@ -133,6 +133,36 @@ sub is_correct_snapshot {
 
 EventStore::Tiny - A minimal event sourcing framework.
 
+=begin html
+
+<p>
+
+<a href="https://badge.fury.io/pl/EventStore-Tiny">
+    <img alt="CPAN version" src="https://badge.fury.io/pl/EventStore-Tiny.svg"></a>
+<a href="https://travis-ci.org/memowe/EventStore-Tiny">
+    <img alt="Travis CI tests" src="https://travis-ci.org/memowe/EventStore-Tiny.svg?branch=master"></a>
+<a href="https://codecov.io/gh/memowe/EventStore-Tiny">
+    <img alt="Codecov test coverage" src="https://codecov.io/gh/memowe/EventStore-Tiny/branch/master/graph/badge.svg"></a>
+<a href="https://coveralls.io/github/memowe/EventStore-Tiny?branch=master">
+    <img alt="Coveralls test coverage" src="https://coveralls.io/repos/github/memowe/EventStore-Tiny/badge.svg?branch=master"></a>
+<a href="http://cpants.cpanauthors.org/dist/EventStore-Tiny">
+    <img alt="CPANTS kwalitee score" src="https://cpants.cpanauthors.org/dist/EventStore-Tiny.png"></a>
+
+<br>
+
+<a href="http://www.cpantesters.org/distro/E/EventStore-Tiny.html?distmat=1">
+    <img alt="CPAN testers reports" src="https://img.shields.io/badge/testers-reports-blue.svg"></a>
+<a href="http://matrix.cpantesters.org/?dist=EventStore-Tiny">
+    <img alt="CPAN testers matrix" src="https://img.shields.io/badge/testers-matrix-blue.svg"></a>
+<a href="https://github.com/memowe/EventStore-Tiny">
+    <img alt="GitHub repository" src="https://img.shields.io/badge/github-code-blue.svg"></a>
+<a href="https://github.com/memowe/EventStore-Tiny/issues">
+    <img alt="GitHub issue tracker" src="https://img.shields.io/badge/github-issues-blue.svg"></a>
+
+</p>
+
+=end html
+
 =head1 SYNOPSIS
 
     use EventStore::Tiny;
@@ -203,7 +233,7 @@ Standard constructor. Understands all attributes as arguments. For most use case
 
 A hashref representing the initial state. B<Default: C<{}>>
 
-=item cache_size
+=item cache_distance
 
 The number of events after a new snapshot is cached for accellerated access. 0 means the cache is updated after each event. undef means the system does not use any caching. B<Default: 0>
 
@@ -294,7 +324,7 @@ EventStore::Tiny's source repository is hosted on L<GitHub|https://github.com/me
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2018 Mirko Westermeier (mail: mirko@westermeier.de)
+Copyright (c) 2018 L<Mirko Westermeier|http://mirko.westermeier.de> (L<@memowe|https://github.com/memowe>, L<mirko@westermeier.de|mailto:mirko@westermeier.de>)
 
 Released under the MIT License (see LICENSE.txt for details).
 
@@ -304,11 +334,11 @@ Released under the MIT License (see LICENSE.txt for details).
 
 =item *
 
-Mohammad S Anwar (@manwar)
+Mohammad S Anwar (L<@manwar|https://github.com/manwar>)
 
 =item *
 
-Toby Inkster (@tobyink)
+Toby Inkster (L<@tobyink|https://github.com/tobyink>)
 
 =back
 
