@@ -16,22 +16,25 @@ use Class::Tiny {
 sub BUILD {
     my $self = shift;
 
-    # set non-lazy
+    # Set non-lazy
     $self->name;
     $self->timestamp;
+
+    # Return nothing (will be ignored anyway)
+    return;
 }
 
-# lets transformation work on state by side-effect
+# Lets transformation work on state by side-effect
 sub apply_to {
     my ($self, $state, $logger) = @_;
 
-    # apply the transformation by side effect
+    # Apply the transformation by side effect
     $self->transformation->($state);
 
-    # log this event, if logger present
+    # Log this event, if logger present
     $logger->($self) if defined $logger;
 
-    # returned the same state just in case
+    # Returned the same state just in case
     return $state;
 }
 
